# Description
If reporting a bug:
* finn version or commit:
* Python version:
* Operating System:

Describe the bug you want fixed, the feature you want to see, etc.
If you are requesting a new feature, please say why you think that feature is important and belongs in this library, and any guesses on how to implement it.
